@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Disk-Recovery
    <ja>パーティションスキャナーとディスクリカバリー</ja>
    <kk>Partition scanner and disk recovery</kk>
    <ko>Partition scanner and disk recovery</ko>
+   <ku>Partition scanner and disk recovery</ku>
    <lt>Partition scanner and disk recovery</lt>
    <mk>Partition scanner and disk recovery</mk>
    <mr>Partition scanner and disk recovery</mr>
@@ -49,6 +50,7 @@ Disk-Recovery
    <nb>Partisjonsskanner og diskoppretting</nb>
    <nl_BE>Partition scanner and disk recovery</nl_BE>
    <nl>Partition scanner and disk recovery</nl>
+   <or>Partition scanner and disk recovery</or>
    <pl>Partition scanner and disk recovery</pl>
    <pt_BR>Verificador de partição e recuperação de disco</pt_BR>
    <pt>Pesquisador de partições e recuperação de discos</pt>
@@ -56,6 +58,7 @@ Disk-Recovery
    <ru>Partition scanner and disk recovery</ru>
    <sk>Partition scanner and disk recovery</sk>
    <sl>Pregledovalnik razdelkov in obnova diskov</sl>
+   <so>Partition scanner and disk recovery</so>
    <sq>Skanues pjesësh dhe ringjallje disqesh</sq>
    <sr>Partition scanner and disk recovery</sr>
    <sv>Partitions-skanner och disk-återställning</sv>
